@@ -29,6 +29,7 @@
 #include <QSsl>
 #include <QtGlobal>
 
+#include <KAboutData>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -44,6 +45,7 @@
 #include "commands_p.h"
 #include "connection_p.h"
 #include "ioworker_defaults.h"
+#include "kio_version.h"
 #include "kiocoredebug.h"
 #include "kioglobal_p.h"
 #include "kpasswdserverclient.h"
@@ -114,7 +116,7 @@ public:
 
     UDSEntryList pendingListEntries;
     QElapsedTimer m_timeSinceLastBatch;
-    Connection appConnection;
+    Connection appConnection{Connection::Type::Worker};
     QString poolSocket;
     bool isConnectedToApp;
 
@@ -141,7 +143,7 @@ public:
     bool m_finalityCommand = true; // whether finished() or error() may/must be called
     QByteArray timeoutData;
 
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
     std::unique_ptr<KPasswdServerClient> m_passwdServerClient;
 #endif
     bool m_rootEntryListed = false;
@@ -227,7 +229,7 @@ public:
                                             .arg(QCoreApplication::applicationName())));
     }
 
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
     KPasswdServerClient *passwdServerClient()
     {
         if (!m_passwdServerClient) {
@@ -276,7 +278,12 @@ SlaveBase::SlaveBase(const QByteArray &protocol, const QByteArray &pool_socket,
 
     if (QThread::currentThread() == qApp->thread()) {
 #ifndef Q_OS_ANDROID
-        KCrash::initialize();
+        // Setup KCrash for crash reports, but not when running the worker in-app
+        if (QCoreApplication::arguments()[0].endsWith(QLatin1String("kioworker"))) {
+            KAboutData about(QStringLiteral("kioworker"), QString(), QStringLiteral(KIO_VERSION_STRING));
+            KAboutData::setApplicationData(about);
+            KCrash::initialize();
+        }
 #endif
 
 #ifdef Q_OS_UNIX
@@ -691,11 +698,6 @@ void SlaveBase::redirection(const QUrl &_url)
     send(INF_REDIRECTION, data);
 }
 
-void SlaveBase::errorPage()
-{
-    send(INF_ERROR_PAGE);
-}
-
 static bool isSubCommand(int cmd)
 {
     /* clang-format off */
@@ -997,7 +999,7 @@ int SlaveBase::openPasswordDialogV2(AuthInfo &info, const QString &errorMsg)
     // it to ensure it is valid.
     dlgInfo.setExtraField(QStringLiteral("skip-caching-on-query"), true);
 
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
     KPasswdServerClient *passwdServerClient = d->passwdServerClient();
     const int errCode = passwdServerClient->queryAuthInfo(&dlgInfo, errorMessage, windowId, userTimestamp);
     if (errCode == KJob::NoError) {
@@ -1356,7 +1358,7 @@ void SlaveBase::dispatch(int command, const QByteArray &data)
 
 bool SlaveBase::checkCachedAuthentication(AuthInfo &info)
 {
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
     KPasswdServerClient *passwdServerClient = d->passwdServerClient();
     return (passwdServerClient->checkAuthInfo(&info, metaData(QStringLiteral("window-id")).toLong(), metaData(QStringLiteral("user-timestamp")).toULong()));
 #else
@@ -1406,7 +1408,7 @@ void SlaveBase::dispatchOpenCommand(int command, const QByteArray &data)
 
 bool SlaveBase::cacheAuthentication(const AuthInfo &info)
 {
-#ifndef KIO_ANDROID_STUB
+#ifdef WITH_QTDBUS
     KPasswdServerClient *passwdServerClient = d->passwdServerClient();
     passwdServerClient->addAuthInfo(info, metaData(QStringLiteral("window-id")).toLongLong());
 #endif
